// Loading required modules forthe pie chart.
import { getData } from './getData';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

// declare tags of index.html
const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');
const xAxisTickFormat = number =>
  	format('8~g')(number);

// begin rendering pie chart to html
const render = (data,total) => {
  //
  const pieData = pie().value(d=>d.feb)(data);
  
	// Colors used in Pie Chart
  const colors = scaleOrdinal()
  	.domain(data)
  	.range([
      "green","blue","pink","black","greenyellow",
      "orange","coral","magenta","saddlebrown","cyan",
      "lime"
    ]);
  
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(180)
  	.padAngle(0)
  	.padRadius(0);
  // section of pie chart
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);

  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.feb));
  
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*25})`;
    });
  
  
  // legend colors to pie chart. 
  legend.append("rect").attr("width",15).attr("height",15)
  	.attr("fill", d => colors(d.data.feb));
    
  legend.append("text")
  	.attr("x", 26)
  	.attr("y", 16)
  	.attr("class","legend_text")
  	.text(d => d.data.Car);
  
  //car price values  
  legend.append("text")
  	.attr("x", 180)
  	.attr("y", 16)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat(((d.data.feb/total)*100).toFixed(1))+"%");
    
  legend.append("text")
  	.attr("x", 255)
  	.attr("y", 18)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.feb/1000))+"K");
}

// loading data from gist 
const run = async () => {
  let data = await getData()
  let total = 0
  data.forEach(d=>{
    d.feb = +d.feb;
    total += d.feb
  });
	render(data,total);
};
run();